Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(878)

Unified Diff: jingle/notifier/communicator/ssl_socket_adapter.h

Issue 3358028: Revert r59012 which started using Chrome sockets for sync. (Closed) Base URL: http://src.chromium.org/git/chromium.git
Patch Set: Created 10 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: jingle/notifier/communicator/ssl_socket_adapter.h
diff --git a/remoting/jingle_glue/ssl_socket_adapter.h b/jingle/notifier/communicator/ssl_socket_adapter.h
similarity index 93%
rename from remoting/jingle_glue/ssl_socket_adapter.h
rename to jingle/notifier/communicator/ssl_socket_adapter.h
index a22e2b709e59cc8ec3c90c54d85257caea7cb565..cdbc94e2e41fa44cdeafadc588a1b6118068eb4a 100644
--- a/remoting/jingle_glue/ssl_socket_adapter.h
+++ b/jingle/notifier/communicator/ssl_socket_adapter.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef REMOTING_JINGLE_GLUE_SSL_SOCKET_ADAPTER_H_
-#define REMOTING_JINGLE_GLUE_SSL_SOCKET_ADAPTER_H_
+#ifndef JINGLE_NOTIFIER_COMMUNICATOR_SSL_SOCKET_ADAPTER_H_
+#define JINGLE_NOTIFIER_COMMUNICATOR_SSL_SOCKET_ADAPTER_H_
#include "base/scoped_ptr.h"
#include "net/base/completion_callback.h"
@@ -15,7 +15,7 @@
#include "talk/base/asyncsocket.h"
#include "talk/base/ssladapter.h"
-namespace remoting {
+namespace notifier {
class SSLSocketAdapter;
@@ -81,7 +81,7 @@ class TransportSocket : public net::ClientSocket, public sigslot::has_slots<> {
};
// This provides a talk_base::AsyncSocketAdapter interface around Chromium's
// net::SSLClientSocket class. This allows remoting to use Chromium's SSL
// implementation instead of OpenSSL.
class SSLSocketAdapter : public talk_base::SSLAdapter {
public:
@@ -140,6 +140,6 @@ class SSLSocketAdapter : public talk_base::SSLAdapter {
DISALLOW_COPY_AND_ASSIGN(SSLSocketAdapter);
};
-} // namespace remoting
+} // namespace notifier
-#endif // REMOTING_JINGLE_GLUE_SSL_SOCKET_ADAPTER_H_
+#endif // JINGLE_NOTIFIER_COMMUNICATOR_SSL_SOCKET_ADAPTER_H_
« no previous file with comments | « jingle/notifier/communicator/single_login_attempt.cc ('k') | jingle/notifier/communicator/ssl_socket_adapter.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -81,7 +81,7 @@ class TransportSocket : public net::ClientSocket, public sigslot::has_slots<> {
};
// This provides a talk_base::AsyncSocketAdapter interface around Chromium's
-// net::SSLClientSocket class. This allows remoting to use Chromium's SSL
+// net::SSLClientSocket class. This allows notifier to use Chromium's SSL
// implementation instead of OpenSSL.
class SSLSocketAdapter : public talk_base::SSLAdapter {
This is Rietveld 408576698